This python package implements Normal(Gaussian) and Binomial distributions and provides data structures and wrapper to create custom statistical distributions leveraging the general distribution class.

For ease of statistical analysis, a simple command can be used to call any of the above classes:
from distributions import Gaussian
from distributions import Binomial
